##
# This script is used for mc.respond.tcl, by MC_8.  Do not edit this
# script, you make all your configuration changes in mc.respond.tcl.
##


##
# soundex v2.0 ported and recoded in TCL
#   by MC_8 - Carl M. Gregory <gregory@worldinter.net>
##
#
# Implementation of soundex algorithm as described by Knuth in volume
# 3 of The Art of Computer Programming, with ideas stolen from Ian
# Phillips <ian@pipex.net>, and ported over to TCL by
# Carl M. Gregory <gregory@worldinter.net>.  Ported over from perl,
# perl coded by Mike Stok <Mike.Stok@meiko.concord.ma.us>, 2 March 1994.
#
# Knuth's test cases are:
# 
# Euler, Ellery -> E460
# Gauss, Ghosh -> G200
# Hilbert, Heilbronn -> H416
# Knuth, Kant -> K530
# Lloyd, Ladd -> L300
# Lukasiewicz, Lissajous -> L222
#
# Syntax:
#  soundex <string>
#   returns: soundex string
#            if the string contains a non alpha character,
#            it will return the origional word (but continues to convert the rest)
#
# In this version (2), it's not returned as ANNN (A= Alpha, N= Numberic).  Rather
# returns in NNNNNNNNNNNN.  This is to fix the sensitivity of the first character
# within a string.  I have tested, and it looks to work just fine... but since 
# this idea (soundex) goes back to at least 1918, I wonder why it wasn't 
# implimented a long time ago... maby there is a bug in doing it this way, I 
# don't know.
#
# Also, KN == K, GHT == T, GHN == N , TCH == CH.
#  -- Carl M. Gregory
#
##

proc soundex {arg} {
 set return ""
 if {[string match *\[\000-\039\041-\100\108\109\118\119\128\129\133-\140\148\149\158\159\168\169\173-\300\]* $arg]} {
  set spcchr 1
 } else {set spcchr 0}
 foreach word [join [split [join [split [join [split [join [split [join [split [join [split $arg \\] \\\\] \[] \\\[] \]] \\\]] \}] \\\}] \{] \\\{] \"] \\\"] {
  if {$spcchr && [string match *\[\000-\039\041-\100\108\109\118\119\128\129\133-\140\148\149\158\159\168\169\173-\300\]* $word]} {
   append return " $word";continue
  };set word [string toupper $word]
  regsub -all -- KN $word K word
  regsub -all -- GHT $word T word
  regsub -all -- GHN $word N word
  regsub -all -- TCH $word CH word
  set word [join [split [join [split [join [split [join [split [join [split [join [split [join [split $word AEHIOUWY] 0] BFPV] 1] CGJKQSXZ] 2] DT] 3] L] 4] MN] 5] R] 6]
  while {[string match *00* $word]} {regsub -all -- 00 $word 0 word}
  while {[string match *11* $word]} {regsub -all -- 11 $word 1 word}
  while {[string match *22* $word]} {regsub -all -- 22 $word 2 word}
  while {[string match *33* $word]} {regsub -all -- 33 $word 3 word}
  while {[string match *44* $word]} {regsub -all -- 44 $word 4 word}
  while {[string match *55* $word]} {regsub -all -- 55 $word 5 word}
  while {[string match *66* $word]} {regsub -all -- 66 $word 6 word}
  set word [join [split $word 0] {}]
  append return " [string range "${word}000000000000" 0 11]"
 };return [string range $return 1 e]
}